/* file: distributedmaster.cpp */
/*******************************************************************************
* Copyright 2014-2021 Intel Corporation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*******************************************************************************/

#include <jni.h>
#include <daal.h>

#include "com_intel_daal_algorithms_pca_DistributedStep2Master.h"
#include "com_intel_daal_algorithms_pca_Method.h"

#include "com/intel/daal/common_helpers.h"

#define CorrelationDenseValue com_intel_daal_algorithms_pca_Method_correlationDenseValue
#define SVDDenseValue         com_intel_daal_algorithms_pca_Method_svdDenseValue

USING_COMMON_NAMESPACES();
using namespace daal::algorithms::pca;

/*
 * Class:     com_intel_daal_algorithms_pca_DistributedStep2Master
 * Method:    cInit
 * Signature: (II)J
 */
JNIEXPORT jlong JNICALL Java_com_intel_daal_algorithms_pca_DistributedStep2Master_cInit(JNIEnv * env, jobject thisObj, jint prec, jint method)
{
    return jniDistributed<step2Master, pca::Method, Distributed, correlationDense, svdDense>::newObj(prec, method);
}

/*
 * Class:     com_intel_daal_algorithms_pca_DistributedStep2Master
 * Method:    cInitParameter
 * Signature: (JII)J
 */
JNIEXPORT jlong JNICALL Java_com_intel_daal_algorithms_pca_DistributedStep2Master_cInitParameter(JNIEnv * env, jobject thisObj, jlong algAddr,
                                                                                                 jint prec, jint method)
{
    return jniDistributed<step2Master, pca::Method, Distributed, correlationDense, svdDense>::getParameter(prec, method, algAddr);
}

/*
 * Class:     com_intel_daal_algorithms_pca_DistributedStep2Master
 * Method:    cGetInput
 * Signature: (JII)J
 */
JNIEXPORT jlong JNICALL Java_com_intel_daal_algorithms_pca_DistributedStep2Master_cGetInput(JNIEnv * env, jobject thisObj, jlong algAddr, jint prec,
                                                                                            jint method)
{
    return jniDistributed<step2Master, pca::Method, Distributed, correlationDense, svdDense>::getInput(prec, method, algAddr);
}

/*
 * Class:     com_intel_daal_algorithms_pca_DistributedStep2Master
 * Method:    cGetResult
 * Signature: (JII)J
 */
JNIEXPORT jlong JNICALL Java_com_intel_daal_algorithms_pca_DistributedStep2Master_cGetResult(JNIEnv * env, jobject thisObj, jlong algAddr, jint prec,
                                                                                             jint method)
{
    return jniDistributed<step2Master, pca::Method, Distributed, correlationDense, svdDense>::getResult(prec, method, algAddr);
}

/*
 * Class:     com_intel_daal_algorithms_pca_DistributedStep2Master
 * Method:    cGetPartialResult
 * Signature: (JII)J
 */
JNIEXPORT jlong JNICALL Java_com_intel_daal_algorithms_pca_DistributedStep2Master_cGetPartialResult(JNIEnv * env, jobject thisObj, jlong algAddr,
                                                                                                    jint prec, jint method)
{
    return jniDistributed<step2Master, pca::Method, Distributed, correlationDense, svdDense>::getPartialResult(prec, method, algAddr);
}

/*
 * Class:     com_intel_daal_algorithms_pca_DistributedStep2Master
 * Method:    cSetResult
 * Signature: (JIIJ)V
 */
JNIEXPORT void JNICALL Java_com_intel_daal_algorithms_pca_DistributedStep2Master_cSetResult(JNIEnv * env, jobject thisObj, jlong algAddr, jint prec,
                                                                                            jint method, jlong resultAddr)
{
    jniDistributed<step2Master, pca::Method, Distributed, correlationDense, svdDense>::setResult<pca::Result>(prec, method, algAddr, resultAddr);
}

/*
 * Class:     com_intel_daal_algorithms_pca_DistributedStep2Master
 * Method:    cSetPartialResult
 * Signature: (JIIJZ)V
 */
JNIEXPORT void JNICALL Java_com_intel_daal_algorithms_pca_DistributedStep2Master_cSetPartialResult(JNIEnv * env, jobject thisObj, jlong algAddr,
                                                                                                   jint prec, jint method, jlong partialResultAddr,
                                                                                                   jboolean initFlag)
{
    jniDistributed<step2Master, pca::Method, Distributed, correlationDense, svdDense>::setPartialResultImpl<pca::PartialResult>(prec, method, algAddr,
                                                                                                                                partialResultAddr);
}

/*
 * Class:     com_intel_daal_algorithms_pca_DistributedStep2Master
 * Method:    cClone
 * Signature: (JII)J
 */
JNIEXPORT jlong JNICALL Java_com_intel_daal_algorithms_pca_DistributedStep2Master_cClone(JNIEnv * env, jobject thisObj, jlong algAddr, jint prec,
                                                                                         jint method)
{
    return jniDistributed<step2Master, pca::Method, Distributed, correlationDense, svdDense>::getClone(prec, method, algAddr);
}
