/* file: ResultId.java */
/*******************************************************************************
* Copyright 2014-2021 Intel Corporation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*******************************************************************************/

/**
 * @ingroup pivoted_qr
 * @{
 */
package com.intel.daal.algorithms.pivoted_qr;

import java.lang.annotation.Native;

import com.intel.daal.utils.*;
/**
 * <a name="DAAL-CLASS-ALGORITHMS__PIVOTED_QR__RESULTID"></a>
 * @brief Available types of the results of the pivoted QR algorithm
 */
public final class ResultId {
    /** @private */
    static {
        LibUtils.loadLibrary();
    }

    private int _value;

    /**
     * Constructs the result object identifier using the provided value
     * @param value     Value corresponding to the result object identifier
     */
    public ResultId(int value) {
        _value = value;
    }

    /**
     * Returns the value corresponding to the result object identifier
     * @return Value corresponding to the result object identifier
     */
    public int getValue() {
        return _value;
    }

    @Native private static final int matrixQId           = 0;
    @Native private static final int matrixRId           = 1;
    @Native private static final int permutationMatrixId = 2;

    public static final ResultId matrixQ           = new ResultId(matrixQId); /*!< Orthogonal Matrix Q */
    public static final ResultId matrixR           = new ResultId(matrixRId); /*!< Upper Triangular Matrix R */
    public static final ResultId permutationMatrix = new ResultId(
            permutationMatrixId);                                             /*!< The permutation matrix P overwritten by its details */
}
/** @} */
